summaryrefslogtreecommitdiff
path: root/MdeModulePkg/Include
diff options
context:
space:
mode:
authorlgao4 <lgao4@6f19259b-4bc3-4df7-8a09-765794883524>2008-12-03 08:55:36 +0000
committerlgao4 <lgao4@6f19259b-4bc3-4df7-8a09-765794883524>2008-12-03 08:55:36 +0000
commit346cf9ace3b51e3d40019ce7f6fee24375f829cc (patch)
tree7a26175ceed93fcbe9ba3573ef77c9b356ea2e4d /MdeModulePkg/Include
parentaa79b0b3799e95bc21e0df32a135cc5a4d749e4b (diff)
downloadedk2-platforms-346cf9ace3b51e3d40019ce7f6fee24375f829cc.tar.xz
Code scrub for MdeModule Include header file (Protocol and DEC)
git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@6817 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'MdeModulePkg/Include')
-rw-r--r--MdeModulePkg/Include/Guid/SimpleTextInExNotify.h25
-rw-r--r--MdeModulePkg/Include/Ppi/BaseMemoryTest.h15
-rw-r--r--MdeModulePkg/Include/Ppi/OperatorPresence.h4
-rw-r--r--MdeModulePkg/Include/Protocol/Capsule.h2
-rw-r--r--MdeModulePkg/Include/Protocol/ConsoleControl.h18
-rw-r--r--MdeModulePkg/Include/Protocol/Crc32GuidedSectionExtraction.h9
-rw-r--r--MdeModulePkg/Include/Protocol/DiskInfo.h8
-rw-r--r--MdeModulePkg/Include/Protocol/FaultTolerantWriteLite.h12
-rw-r--r--MdeModulePkg/Include/Protocol/FirmwareVolumeDispatch.h3
-rw-r--r--MdeModulePkg/Include/Protocol/FvbExtension.h10
-rw-r--r--MdeModulePkg/Include/Protocol/GenericMemoryTest.h50
-rw-r--r--MdeModulePkg/Include/Protocol/LoadPe32Image.h22
-rw-r--r--MdeModulePkg/Include/Protocol/OEMBadging.h8
-rw-r--r--MdeModulePkg/Include/Protocol/Performance.h10
-rw-r--r--MdeModulePkg/Include/Protocol/Print.h4
-rw-r--r--MdeModulePkg/Include/Protocol/Print2.h6
-rw-r--r--MdeModulePkg/Include/VariableFormat.h2
17 files changed, 113 insertions, 95 deletions
diff --git a/MdeModulePkg/Include/Guid/SimpleTextInExNotify.h b/MdeModulePkg/Include/Guid/SimpleTextInExNotify.h
new file mode 100644
index 0000000000..7e4ae41355
--- /dev/null
+++ b/MdeModulePkg/Include/Guid/SimpleTextInExNotify.h
@@ -0,0 +1,25 @@
+/** @file
+ This file defines Simple TextInEx Notify Guid that specify the notify handle.
+
+Copyright (c) 2008, Intel Corporation. <BR>
+All rights reserved. This program and the accompanying materials
+are licensed and made available under the terms and conditions of the BSD License
+which accompanies this distribution. The full text of the license may be found at
+http://opensource.org/licenses/bsd-license.php
+
+THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
+WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+
+**/
+
+#ifndef _SIMPLE_TEXTIN_EX_NOTIFY__H_
+#define _SIMPLE_TEXTIN_EX_NOTIFY__H_
+
+#define SIMPLE_TEXTIN_EX_NOTIFY_GUID \
+ { \
+ 0x856f2def, 0x4e93, 0x4d6b, {0x94, 0xce, 0x1c, 0xfe, 0x47, 0x1, 0x3e, 0xa5} \
+ }
+
+extern EFI_GUID gSimpleTextInExNotifyGuid;
+
+#endif
diff --git a/MdeModulePkg/Include/Ppi/BaseMemoryTest.h b/MdeModulePkg/Include/Ppi/BaseMemoryTest.h
index f7c6d617d3..1e0fbb4af7 100644
--- a/MdeModulePkg/Include/Ppi/BaseMemoryTest.h
+++ b/MdeModulePkg/Include/Ppi/BaseMemoryTest.h
@@ -1,5 +1,5 @@
/** @file
- This file defines Pei memory test PPI used to Perform memory test in PEI phase.
+ This file defines Pei memory test PPI used to perform memory test in PEI phase.
Copyright (c) 2006 - 2008, Intel Corporation. <BR>
All rights reserved. This program and the accompanying materials
@@ -20,10 +20,10 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
typedef struct _PEI_BASE_MEMORY_TEST_PPI PEI_BASE_MEMORY_TEST_PPI;
-//
-// 4 different test operations
-// Ignore op not test memory, Quick and Sparse op test memory quickly, Extensive op test memory detailedly.
-//
+///
+/// Pei Memory test operations
+/// Ignore op not test memory, Quick and Sparse op test memory quickly, Extensive op test memory detailedly.
+///
typedef enum {
Ignore,
Quick,
@@ -32,14 +32,15 @@ typedef enum {
} PEI_MEMORY_TEST_OP;
/**
- Test a range memory space is ready to read and write.
+ Test a range memory space that is ready to read and write.
+ If the memory is not ready, the error memory address will be returned.
@param PeiServices An indirect pointer to the PEI Services Table published by the PEI Foundation.
@param This Pointer to Pei memory test PPI instance.
@param BeginAddress Beginning of the memory address to be checked.
@param MemoryLength Bytes of memory range to be checked.
@param Operation Type of memory check operation to be performed.
- @param ErrorAddress Address which has error when checked.
+ @param ErrorAddress Address of memory where the error is checked.
@retval EFI_SUCCESS Memory range pass basic read and write test.
@retval EFI_DEVICE_ERROR Memory is not ready to access.
diff --git a/MdeModulePkg/Include/Ppi/OperatorPresence.h b/MdeModulePkg/Include/Ppi/OperatorPresence.h
index b5221a13ab..e31a76002d 100644
--- a/MdeModulePkg/Include/Ppi/OperatorPresence.h
+++ b/MdeModulePkg/Include/Ppi/OperatorPresence.h
@@ -1,5 +1,5 @@
/** @file
- This file defines OperatorPresent PPI responsible for detecting TPM operator presence.
+ This file defines OperatorPresent PPI. It is responsible for detecting TPM operator presence.
Copyright (c) 2006 - 2008, Intel Corporation. <BR>
All rights reserved. This program and the accompanying materials
@@ -21,7 +21,7 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
typedef struct _PEI_OPERATOR_PRESENCE_PPI PEI_OPERATOR_PRESENCE_PPI;
struct _PEI_OPERATOR_PRESENCE_PPI {
- BOOLEAN OperatorPresent;
+ BOOLEAN OperatorPresent; /// TRUE if TPM Operator is detected.
};
extern EFI_GUID gPeiOperatorPresencePpiGuid;
diff --git a/MdeModulePkg/Include/Protocol/Capsule.h b/MdeModulePkg/Include/Protocol/Capsule.h
index 7c8e258137..fad7bb928a 100644
--- a/MdeModulePkg/Include/Protocol/Capsule.h
+++ b/MdeModulePkg/Include/Protocol/Capsule.h
@@ -1,7 +1,7 @@
/** @file
Capsule Architectural Protocol is responsible to tag UEFI2.0 capsule runtime services
- are ready in EFI_RUNTIME_SERVICES.
+ are ready in EFI_RUNTIME_SERVICES table.
Copyright (c) 2006 - 2008, Intel Corporation
All rights reserved. This program and the accompanying materials
diff --git a/MdeModulePkg/Include/Protocol/ConsoleControl.h b/MdeModulePkg/Include/Protocol/ConsoleControl.h
index b14b54d028..b2111ef9bb 100644
--- a/MdeModulePkg/Include/Protocol/ConsoleControl.h
+++ b/MdeModulePkg/Include/Protocol/ConsoleControl.h
@@ -23,18 +23,18 @@ typedef struct _EFI_CONSOLE_CONTROL_PROTOCOL EFI_CONSOLE_CONTROL_PROTOCOL;
typedef enum {
- EfiConsoleControlScreenText,
- EfiConsoleControlScreenGraphics,
+ EfiConsoleControlScreenText, /// Text Mode
+ EfiConsoleControlScreenGraphics, /// Graphics Mode
EfiConsoleControlScreenMaxValue
} EFI_CONSOLE_CONTROL_SCREEN_MODE;
/**
Return the current video mode information. Also returns info about existence
- of Graphics Output devices or UGA Draw devices in system, and if the Std In device is locked. All the
- arguments are optional and only returned if a non NULL pointer is passed in.
+ of Graphics Output devices or UGA Draw devices in system, and whether the Std In device is locked.
+ GopUgaExists and StdInLocked parameters are optional.
@param This Protocol instance pointer.
- @param Mode Are we in text of grahics mode.
+ @param Mode Current video mode.
@param GopExists TRUE if GOP Spliter has found a GOP/UGA device
@param StdInLocked TRUE if StdIn device is keyboard locked
@@ -55,9 +55,9 @@ EFI_STATUS
Set the current video mode to either text or graphics.
@param This Protocol instance pointer.
- @param Mode Mode is to be set.
+ @param Mode Video mode is to be set.
- @retval EFI_SUCCESS Mode is set.
+ @retval EFI_SUCCESS Mode is set successfully.
@retval EFI_INVALID_PARAMETER Mode is not the valid mode value.
@retval EFI_UNSUPPORTED Mode is unsupported by console device.
@@ -70,9 +70,9 @@ EFI_STATUS
);
/**
- Copy the Password and enable state variable and then arm the periodic timer
+ Store the password, enable state variable and arm the periodic timer.
- @retval EFI_SUCCESS Lock the StdIn device
+ @retval EFI_SUCCESS Lock the StdIn device successfully.
@retval EFI_INVALID_PARAMETER Password is NULL
@retval EFI_OUT_OF_RESOURCES Buffer allocation to store the big password fails
diff --git a/MdeModulePkg/Include/Protocol/DiskInfo.h b/MdeModulePkg/Include/Protocol/DiskInfo.h
index 98ecd7695e..cbbea8f996 100644
--- a/MdeModulePkg/Include/Protocol/DiskInfo.h
+++ b/MdeModulePkg/Include/Protocol/DiskInfo.h
@@ -1,7 +1,6 @@
/** @file
Disk Info protocol is used to export Inquiry Data for a drive.
- Its needed to support low level formating of drives in a mannor
- thats DOS compatible.
+ It supports low level formating of drives in a DOS compatible manner.
Copyright (c) 2006 - 2008, Intel Corporation. <BR>
All rights reserved. This program and the accompanying materials
@@ -98,8 +97,7 @@ EFI_STATUS
);
/**
- Return the results of the Request Sense command to a drive in SenseData.
- Data format of Sense data is defined by the Interface GUID.
+ Return the IDE device information.
@param This Protocol instance pointer.
@param IdeChannel Primary or Secondary
@@ -146,7 +144,7 @@ extern EFI_GUID gEfiDiskInfoUsbInterfaceGuid;
extern EFI_GUID gEfiDiskInfoAhciInterfaceGuid;
struct _EFI_DISK_INFO_PROTOCOL {
- EFI_GUID Interface;
+ EFI_GUID Interface; /// The format of the buffers returned by member functions.
EFI_DISK_INFO_INQUIRY Inquiry;
EFI_DISK_INFO_IDENTIFY Identify;
EFI_DISK_INFO_SENSE_DATA SenseData;
diff --git a/MdeModulePkg/Include/Protocol/FaultTolerantWriteLite.h b/MdeModulePkg/Include/Protocol/FaultTolerantWriteLite.h
index 4a0e495267..368279f68d 100644
--- a/MdeModulePkg/Include/Protocol/FaultTolerantWriteLite.h
+++ b/MdeModulePkg/Include/Protocol/FaultTolerantWriteLite.h
@@ -29,18 +29,16 @@ typedef struct _EFI_FTW_LITE_PROTOCOL EFI_FTW_LITE_PROTOCOL;
//
/**
Starts a target block update. This records information about the write
- in fault tolerant storage and will complete the write in a recoverable
+ in fault tolerant storage will complete the write in a recoverable
manner, ensuring at all times that either the original contents or
the modified contents are available.
@param This The pointer to this protocol instance.
- @param FvBlockHandle The handle of FVB protocol that provides services
- for reading, writing, and erasing the target
- block.
+ @param FvbHandle The handle of FVB protocol that provides services
+ for reading, writing, and erasing the target block.
@param Lba The logical block address of the target block.
- @param Offset The offset within the target block to place the
- data.
- @param Length The number of bytes to write to the target block.
+ @param Offset The offset within the target block to place the data.
+ @param NumBytes The number of bytes to write to the target block.
@param Buffer The data to write.
@retval EFI_SUCCESS The function completed successfully
diff --git a/MdeModulePkg/Include/Protocol/FirmwareVolumeDispatch.h b/MdeModulePkg/Include/Protocol/FirmwareVolumeDispatch.h
index 27fd1b14dc..81ced024b5 100644
--- a/MdeModulePkg/Include/Protocol/FirmwareVolumeDispatch.h
+++ b/MdeModulePkg/Include/Protocol/FirmwareVolumeDispatch.h
@@ -1,7 +1,8 @@
/** @file
This file declares Firmware Volume Dispatch protocol.
- Presence of this protocol tells the core dispatcher to dispatch this Firmware Volume.
+ This protocol will be installed into FV Handle if the drivers in this Firmware Volume
+ are required to be dispatched by the core dispatcher.
Copyright (c) 2006 - 2008, Intel Corporation
All rights reserved. This program and the accompanying materials
diff --git a/MdeModulePkg/Include/Protocol/FvbExtension.h b/MdeModulePkg/Include/Protocol/FvbExtension.h
index 6f6621b132..f3918e9490 100644
--- a/MdeModulePkg/Include/Protocol/FvbExtension.h
+++ b/MdeModulePkg/Include/Protocol/FvbExtension.h
@@ -1,6 +1,7 @@
/** @file
- FVB Extension protocol that extends the FVB Class in a component fashion.
+ FVB Extension protocol provides one extended service to FVB protocol defined in PI specification.
+ This service can erase the specified range of a firmware volume block.
Copyright (c) 2006 - 2008, Intel Corporation
All rights reserved. This program and the accompanying materials
@@ -25,12 +26,11 @@ typedef struct _EFI_FVB_EXTENSION_PROTOCOL EFI_FVB_EXTENSION_PROTOCOL;
// FVB Extension Function Prototypes
//
/**
- Erases and initializes a specified range of a firmware volume block
+ Erases and initializes a specified range of a firmware volume block.
@param[in] This Pointer to the FVB Extension protocol instance
@param[in] StartLba The starting logical block index to be erased
- @param[in] OffsetStartLba Offset into the starting block at which to
- begin erasing
+ @param[in] OffsetStartLba Offset into the starting block at which to begin erasing
@param[in] LastLba The last logical block index to be erased
@param[in] OffsetLastLba Offset into the last block at which to end erasing
@@ -38,7 +38,7 @@ typedef struct _EFI_FVB_EXTENSION_PROTOCOL EFI_FVB_EXTENSION_PROTOCOL;
@retval EFI_ACCESS_DENIED The firmware volume block is in the WriteDisabled state
@retval EFI_DEVICE_ERROR The block device is not functioning correctly and
could not be written. Firmware device may have been
- partially erased
+ partially erased.
**/
typedef
EFI_STATUS
diff --git a/MdeModulePkg/Include/Protocol/GenericMemoryTest.h b/MdeModulePkg/Include/Protocol/GenericMemoryTest.h
index 57ef1493b4..3b0614ad82 100644
--- a/MdeModulePkg/Include/Protocol/GenericMemoryTest.h
+++ b/MdeModulePkg/Include/Protocol/GenericMemoryTest.h
@@ -1,5 +1,5 @@
/** @file
- This protocol defines the EFI generic memory test interfaces in Dxe phase.
+ This protocol defines the generic memory test interfaces in Dxe phase.
Copyright (c) 2006 - 2008, Intel Corporation. <BR>
All rights reserved. This program and the accompanying materials
@@ -20,6 +20,10 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
typedef struct _EFI_GENERIC_MEMORY_TEST_PROTOCOL EFI_GENERIC_MEMORY_TEST_PROTOCOL;
+///
+/// Memory test coverage level
+/// Ignore op not test memory, Quick and Sparse op test memory quickly, Extensive op test memory detailedly.
+///
typedef enum {
IGNORE,
QUICK,
@@ -36,11 +40,10 @@ typedef enum {
@param Level The coverage level of the memory test.
@param RequireSoftECCInit Indicate if the memory need software ECC init.
- @retval EFI_SUCCESS The generic memory test initialized correctly.
- @retval EFI_NO_MEDIA There is not any non-tested memory found, in this
- function if not any non-tesed memory found means
+ @retval EFI_SUCCESS The generic memory test is initialized correctly.
+ @retval EFI_NO_MEDIA There is not any non-tested memory found, which means
that the memory test driver have not detect any
- non-tested extended memory of current system.
+ non-tested extended memory in current system.
**/
typedef
@@ -58,24 +61,20 @@ EFI_STATUS
@param This Protocol instance pointer.
@param TestedMemorySize Return the tested extended memory size.
@param TotalMemorySize Return the whole system physical memory size, this
- value may be changed if in some case some error
- DIMMs be disabled.
- @param ErrorOut Any time the memory error occurs, this will be
- TRUE.
- @param IfTestAbort Indicate if the user press "ESC" to skip the memory
- test.
-
- @retval EFI_SUCCESS One block of memory test ok, the block size is hide
- internally.
- @retval EFI_NOT_FOUND Indicate all the non-tested memory blocks have
- already go through.
- @retval EFI_DEVICE_ERROR Mis-compare error, and no agent can handle it
+ value may be changed if some error DIMMs is disabled in some case.
+ @param ErrorOut TRUE if the memory error occurs.
+ @param IfTestAbort Indicate if the user press "ESC" to skip the memory test.
+
+ @retval EFI_SUCCESS One block of memory pass test.
+ @retval EFI_NOT_FOUND Indicate all the non-tested memory blocks have been
+ already gone through.
+ @retval EFI_DEVICE_ERROR Memory device error occurs and no agent can handle it.
**/
typedef
EFI_STATUS
(EFIAPI *EFI_PERFORM_MEMORY_TEST)(
- IN EFI_GENERIC_MEMORY_TEST_PROTOCOL *This,
+ IN EFI_GENERIC_MEMORY_TEST_PROTOCOL *This,
OUT UINT64 *TestedMemorySize,
OUT UINT64 *TotalMemorySize,
OUT BOOLEAN *ErrorOut,
@@ -84,13 +83,11 @@ EFI_STATUS
/**
- The memory test finished.
+ Finish the memory test.
@param This Protocol instance pointer.
- @retval EFI_SUCCESS Successful free all the generic memory test driver
- allocated resource and notify to platform memory
- test driver that memory test finished.
+ @retval EFI_SUCCESS Successful.
**/
typedef
@@ -100,12 +97,13 @@ EFI_STATUS
);
/**
- Provide capability to test compatible range which used by some sepcial
- driver required using memory range before BDS perform memory test.
+ Provide capability to test compatible range used by some sepcial
+ driver before BDS perform memory test.
@param This Protocol instance pointer.
- @param StartAddress The start address of the memory range.
- @param Length The memory range's length.
+ @param StartAddress The start address of the compatible memory range that
+ must be below 16M.
+ @param Length The compatible memory range's length.
@retval EFI_SUCCESS The compatible memory range pass the memory test.
@retval EFI_INVALID_PARAMETER The compatible memory range must be below 16M.
diff --git a/MdeModulePkg/Include/Protocol/LoadPe32Image.h b/MdeModulePkg/Include/Protocol/LoadPe32Image.h
index 8adfdfc2d2..5fc9be161e 100644
--- a/MdeModulePkg/Include/Protocol/LoadPe32Image.h
+++ b/MdeModulePkg/Include/Protocol/LoadPe32Image.h
@@ -1,13 +1,9 @@
/** @file
- Load File protocol provides capability to load and unload EFI image into
- memory and execute it.
+ Load Pe32 Image protocol provides capability to load and unload EFI image into memory and execute it.
- Load file protocol exists to supports the addition of new boot devices,
- and to support booting from devices that do not map well to file system.
- Network boot is done via a LoadFile protocol.
-
- UEFI 2.0 can boot from any device that produces a LoadFile protocol.
+ This protocol supports the additional new boot devices that do not map well to file system.
+ UEFI can boot from any device (including Network boot) that produces a LoadFile protocol.
Copyright (c) 2006 - 2008, Intel Corporation
All rights reserved. This program and the accompanying materials
@@ -36,7 +32,7 @@ typedef struct _EFI_PE32_IMAGE_PROTOCOL EFI_PE32_IMAGE_PROTOCOL;
Loads an EFI image into memory and returns a handle to the image with extended parameters.
- @param This Calling context
+ @param This Pointer to the LoadPe32Image protocol instance
@param ParentImageHandle The caller's image handle.
@param FilePath The specific file path from which the image is loaded.
@param SourceBuffer If not NULL, a pointer to the memory location containing a copy of
@@ -54,7 +50,7 @@ typedef struct _EFI_PE32_IMAGE_PROTOCOL EFI_PE32_IMAGE_PROTOCOL;
@retval EFI_INVALID_PARAMETER One of the parameters has an invalid value.
@retval EFI_UNSUPPORTED The image type is not supported, or the device path cannot be
parsed to locate the proper protocol for loading the file.
- @retval EFI_OUT_OF_RESOURCES Image was not loaded due to insufficient resources.
+ @retval EFI_OUT_OF_RESOURCES Image was not loaded due to insufficient memory resources.
**/
typedef
EFI_STATUS
@@ -75,12 +71,12 @@ EFI_STATUS
Unload the specified image.
- @param This Indicates the calling context.
- @param ImageHandle The specified image handle.
+ @param This Pointer to the LoadPe32Image protocol instance
+ @param ImageHandle The specified image handle to be unloaded.
@retval EFI_INVALID_PARAMETER Image handle is NULL.
@retval EFI_UNSUPPORTED Attempt to unload an unsupported image.
- @retval EFI_SUCCESS Image successfully unloaded.
+ @retval EFI_SUCCESS Image is successfully unloaded.
--*/
typedef
@@ -92,7 +88,7 @@ EFI_STATUS
struct _EFI_PE32_IMAGE_PROTOCOL {
LOAD_PE_IMAGE LoadPeImage;
- UNLOAD_PE_IMAGE UnLoadPeImage;
+ UNLOAD_PE_IMAGE UnLoadPeImage;
};
extern EFI_GUID gEfiLoadPeImageProtocolGuid;
diff --git a/MdeModulePkg/Include/Protocol/OEMBadging.h b/MdeModulePkg/Include/Protocol/OEMBadging.h
index 50e013e524..c274dab53c 100644
--- a/MdeModulePkg/Include/Protocol/OEMBadging.h
+++ b/MdeModulePkg/Include/Protocol/OEMBadging.h
@@ -1,6 +1,6 @@
/** @file
- EFI OEM Badging Protocol defines the interface to get the OEM badging
- image with the dispaly attribute. This protocol can be produced based on OEM images.
+ The OEM Badging Protocol defines the interface to get the OEM badging
+ image with the dispaly attribute. This protocol can be produced based on OEM badging images.
Copyright (c) 2006 - 2008, Intel Corporation. <BR>
All rights reserved. This program and the accompanying materials
@@ -48,10 +48,10 @@ typedef enum {
/**
- Load an OEM image and return its data as well as attributes.
+ Load an OEM badge image and return its data as well as attributes.
@param This Pointer to this protocol instance.
- @param Instance The visiable image instance is founded and returned from the input instance.
+ @param Instance The visiable image instance is found.
@param Format Format of the image such as BMP,JPEG,etc.
@param ImageData Image data returned.
@param ImageSize Size of the image returned.
diff --git a/MdeModulePkg/Include/Protocol/Performance.h b/MdeModulePkg/Include/Protocol/Performance.h
index 9df2f6d80b..2581b38b73 100644
--- a/MdeModulePkg/Include/Protocol/Performance.h
+++ b/MdeModulePkg/Include/Protocol/Performance.h
@@ -46,17 +46,17 @@ typedef struct _PERFORMANCE_PROTOCOL PERFORMANCE_PROTOCOL;
typedef struct {
EFI_PHYSICAL_ADDRESS Handle;
- CHAR8 Token[DXE_PERFORMANCE_STRING_SIZE];
- CHAR8 Module[DXE_PERFORMANCE_STRING_SIZE];
- UINT64 StartTimeStamp;
- UINT64 EndTimeStamp;
+ CHAR8 Token[DXE_PERFORMANCE_STRING_SIZE]; /// Measured token string name
+ CHAR8 Module[DXE_PERFORMANCE_STRING_SIZE]; /// Module string name
+ UINT64 StartTimeStamp; /// Start time point
+ UINT64 EndTimeStamp; /// End time point
} GAUGE_DATA_ENTRY;
//
// The header must be aligned at 8 bytes
//
typedef struct {
- UINT32 NumberOfEntries;
+ UINT32 NumberOfEntries; /// The number of all performance guage entries
UINT32 Reserved;
} GAUGE_DATA_HEADER;
diff --git a/MdeModulePkg/Include/Protocol/Print.h b/MdeModulePkg/Include/Protocol/Print.h
index 3faf6f3362..3e26c520f9 100644
--- a/MdeModulePkg/Include/Protocol/Print.h
+++ b/MdeModulePkg/Include/Protocol/Print.h
@@ -1,7 +1,7 @@
/** @file
- This print protocol defines six basic print functions to
- print the format unicode and ascii string.
+ The lite print protocol defines only one print function to
+ print the format unicode string.
Copyright (c) 2006 - 2008, Intel Corporation
All rights reserved. This program and the accompanying materials
diff --git a/MdeModulePkg/Include/Protocol/Print2.h b/MdeModulePkg/Include/Protocol/Print2.h
index 0944341d21..e38a390826 100644
--- a/MdeModulePkg/Include/Protocol/Print2.h
+++ b/MdeModulePkg/Include/Protocol/Print2.h
@@ -94,7 +94,7 @@ UINTN
@param StartOfBuffer A pointer to the output buffer for the produced Null-terminated
Unicode string.
@param BufferSize The size, in bytes, of the output buffer specified by StartOfBuffer.
- @param FormatString Null-terminated Unicode format string.
+ @param FormatString Null-terminated ASCII format string.
@param Marker VA_LIST marker for the variable argument list.
@return The number of Unicode characters in the produced output buffer not including the
@@ -185,7 +185,7 @@ UINTN
@param StartOfBuffer A pointer to the output buffer for the produced Null-terminated
ASCII string.
@param BufferSize The size, in bytes, of the output buffer specified by StartOfBuffer.
- @param FormatString Null-terminated Unicode format string.
+ @param FormatString Null-terminated ASCII format string.
@param Marker VA_LIST marker for the variable argument list.
@return The number of ASCII characters in the produced output buffer not including the
@@ -203,7 +203,7 @@ UINTN
/**
Produces a Null-terminated ASCII string in an output buffer based on a Null-terminated
- ASCII format string and a VA_LIST argument list.
+ Unicode format string and a VA_LIST argument list.
Produces a Null-terminated ASCII string in the output buffer specified by StartOfBuffer
and BufferSize.
diff --git a/MdeModulePkg/Include/VariableFormat.h b/MdeModulePkg/Include/VariableFormat.h
index 72830eccce..4796c49afc 100644
--- a/MdeModulePkg/Include/VariableFormat.h
+++ b/MdeModulePkg/Include/VariableFormat.h
@@ -23,7 +23,7 @@
#endif
///
-/// Hardware error record maximum variable size
+/// Maximum buffer for Hardware error record variable
///
#ifndef MAX_HARDWARE_ERROR_VARIABLE_SIZE
#define MAX_HARDWARE_ERROR_VARIABLE_SIZE FixedPcdGet32(PcdMaxHardwareErrorVariableSize)
diff --git a/MdeModulePkg/Include/Protocol/Crc32GuidedSectionExtraction.h b/MdeModulePkg/Include/Protocol/Crc32GuidedSectionExtraction.h
index 389d53c703..50a8bac6f4 100644
--- a/MdeModulePkg/Include/Protocol/Crc32GuidedSectionExtraction.h
+++ b/MdeModulePkg/Include/Protocol/Crc32GuidedSectionExtraction.h
@@ -1,9 +1,10 @@
/** @file
- This file can define the different guids to specify the different
+ This file defines a group of guids to specify the different
encapsulation scheme for the guided section.
+ The related defintions is in UEFI GuidedSectionExtraction protocol.
+
Now, only one guid is defined for CRC32 encapsulation scheme.
- The related data structures come from the SectionExtraction protocol definition.
Copyright (c) 2006 - 2008, Intel Corporation
All rights reserved. This program and the accompanying materials
@@ -23,13 +24,13 @@
//
// Protocol GUID definition. Each GUIDed section extraction protocol has the
// same interface but with different GUID. All the GUIDs is defined here.
-// May add multiple GUIDs here.
+// May add more GUIDs here in future.
//
#define EFI_CRC32_GUIDED_SECTION_EXTRACTION_PROTOCOL_GUID \
{ 0xFC1BCDB0, 0x7D31, 0x49aa, {0x93, 0x6A, 0xA4, 0x60, 0x0D, 0x9D, 0xD0, 0x83 } }
//
// The data structures are the same as GuidedSectionExtraction protocol only the GUID's are different
//
#include <Protocol/GuidedSectionExtraction.h>
@@ -23,13 +24,13 @@
{ 0xFC1BCDB0, 0x7D31, 0x49aa, {0x93, 0x6A, 0xA4, 0x60, 0x0D, 0x9D, 0xD0, 0x83 } }
//
-// The data structures are the same as GuidedSectionExtraction protocol only the GUID's are different
+// The data structures are the same to UEFI GuidedSectionExtraction protocol.
//
#include <Protocol/GuidedSectionExtraction.h>